# -*- coding: utf-8 -*-
#
# File: Trabalho.py
#
# Copyright (c) 2007 by Associação Python Brasil
# Generator: ArchGenXML 
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PyConBrasil.UIDRenamer import UIDRenamer
from Products.PyConBrasil.config import *

##code-section module-header #fill in your manual code here
import transaction
##/code-section module-header

schema = Schema((

    StringField(
        name='trilha',
        index="FieldIndex:brains",
        widget=SelectionWidget
        (
            description="Selecione a trilha a qual seu trabalho melhor se destina",
            label="Trilha",
            label_msgid='PyConBrasil_label_trilha',
            description_msgid='PyConBrasil_help_trilha',
            i18n_domain='PyConBrasil',
        ),
        enforceVocabulary=True,
        vocabulary='getTrilhas',
        required=True
    ),

    StringField(
        name='titulo',
        index="FieldIndex:brains",
        widget=StringWidget(
            description="Informe o título do trabalho que você está submetendo.",
            label="Título",
            label_msgid='PyConBrasil_label_titulo',
            description_msgid='PyConBrasil_help_titulo',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        searchable=True
    ),

    StringField(
        name='assunto',
        index=":schema",
        widget=StringWidget(
            description="Informe o assunto que trata o trabalho que você está submetendo.",
            label='Assunto',
            label_msgid='PyConBrasil_label_assunto',
            description_msgid='PyConBrasil_help_assunto',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        searchable=True
    ),

    StringField(
        name='nivel',
        index="FieldIndex",
        widget=SelectionWidget
        (
            label="Nível da apresentação",
            description="Informe qual o nível de conhecimento para melhor acompanhamento desta apresentação / treinamento.",
            format="select",
            label_msgid='PyConBrasil_label_nivel',
            description_msgid='PyConBrasil_help_nivel',
            i18n_domain='PyConBrasil',
        ),
        enforceVocabulary=True,
        vocabulary=['Iniciante/Básico', 'Intermediário', 'Avançado'],
        required=True
    ),

    TextField(
        name='resumo',
        widget=TextAreaWidget(
            description="Faça um resumo do seu trabalho.",
            row="10",
            label='Resumo',
            label_msgid='PyConBrasil_label_resumo',
            description_msgid='PyConBrasil_help_resumo',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        searchable=True
    ),

    StringField(
        name='tempo',
        index="FieldIndex:brains",
        widget=SelectionWidget
        (
            description="Duração estimada da apresentação de seu trabalho.",
            label="Tempo estimado",
            label_msgid='PyConBrasil_label_tempo',
            description_msgid='PyConBrasil_help_tempo',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        read_permission="Review portal content",
        vocabulary='getVocTempo',
        enforceVocabulary=True
    ),

    StringField(
        name='nome',
        index=""":schema
        FieldIndex:brains""",
        widget=StringWidget(
            description="Informe o seu nome completo.",
            label='Nome',
            label_msgid='PyConBrasil_label_nome',
            description_msgid='PyConBrasil_help_nome',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        read_permission="View"
    ),

    TextField(
        name='curriculum',
        widget=TextAreaWidget(
            rows="5",
            cols="40",
            label="Curriculum do palestrante",
            description="Apresente, de maneira resumida ,o seu curriculum",
            label_msgid='PyConBrasil_label_curriculum',
            description_msgid='PyConBrasil_help_curriculum',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        searchable=True
    ),

    ImageField(
        name='image',
        widget=ImageWidget(
            label="Foto do Palestrante",
            description="Forneça uma foto sua nas proporções 3x4",
            label_msgid='PyConBrasil_label_image',
            description_msgid='PyConBrasil_help_image',
            i18n_domain='PyConBrasil',
        ),
        storage=AttributeStorage(),
        sizes={'large': (768, 768),'preview':(400, 400),'mini':(200, 200),'thumb': (128, 128),'tile':(64, 64),'icon':(32, 32),'listing':(16, 16),},
    ),

    StringField(
        name='sexo',
        index=":schema",
        widget=SelectionWidget(
            description="Informe o seu sexo.",
            label='Sexo',
            label_msgid='PyConBrasil_label_sexo',
            description_msgid='PyConBrasil_help_sexo',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        read_permission="View",
        vocabulary=['Feminino', 'Masculino'],
        enforceVocabulary=True
    ),

    StringField(
        name='email',
        index="FieldIndex:brains",
        widget=StringWidget(
            label="E-Mail",
            description="Informe o seu endereço eletrônico.",
            label_msgid='PyConBrasil_label_email',
            description_msgid='PyConBrasil_help_email',
            i18n_domain='PyConBrasil',
        ),
        required=1,
        read_permission="Modify portal contents",
        validators=('isEmail',)
    ),

    StringField(
        name='telefone',
        index=":schema",
        widget=StringWidget(
            description="Informe o seu telefone para contato em caso de necessidade. Incluindo o código de área (e país caso fora do Brasil).",
            size=14,
            maxlength=20,
            label='Telefone',
            label_msgid='PyConBrasil_label_telefone',
            description_msgid='PyConBrasil_help_telefone',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        read_permission="Modify portal contents"
    ),

    StringField(
        name='cidade',
        index=":schema",
        widget=StringWidget(
            description="Informe o nome da cidade em que você reside.",
            label='Cidade',
            label_msgid='PyConBrasil_label_cidade',
            description_msgid='PyConBrasil_help_cidade',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        read_permission="View"
    ),

    StringField(
        name='estado',
        index=":schema",
        widget=SelectionWidget(
            description="Selecione o Estado em que você reside.",
            label='Estado',
            label_msgid='PyConBrasil_label_estado',
            description_msgid='PyConBrasil_help_estado',
            i18n_domain='PyConBrasil',
        ),
        required=True,
        read_permission="View",
        vocabulary=ESTADOS,
        enforceVocabulary=True
    ),

    TextField(
        name='endereco',
        index=":schema",
        widget=TextAreaWidget(
            description="Informe o endereço completo em que você reside. Será utilizado caso seja necessário enviar algo para você como por exemplo o certificado de participação.",
            label="Endereço",
            rows="5",
            cols="40",
            label_msgid='PyConBrasil_label_endereco',
            description_msgid='PyConBrasil_help_endereco',
            i18n_domain='PyConBrasil',
        ),
        read_permission="Modify portal contents"
    ),

    StringField(
        name='instituicao',
        index=":schema",
        widget=StringWidget(
            description="Informe o nome da instituição que você representa.",
            label="Instituição",
            label_msgid='PyConBrasil_label_instituicao',
            description_msgid='PyConBrasil_help_instituicao',
            i18n_domain='PyConBrasil',
        ),
        read_permission="Modify portal contents"
    ),

    TextField(
        name='observacoes',
        index=":schema",
        widget=TextAreaWidget(
            description="Descreva aqui qualquer observação que você achar pertinente.",
            label="Observações",
            label_msgid='PyConBrasil_label_observacoes',
            description_msgid='PyConBrasil_help_observacoes',
            i18n_domain='PyConBrasil',
        ),
        read_permission="Modify portal contents"
    ),

    BooleanField(
        name='usoImagem',
        default="False",
        index="FieldIndex:brains",
        widget=BooleanWidget(
            label="Uso de imagem",
            description="Você cede o uso de sua palestra para a Fundação Python Brasil disponibilizar os vídeos e materiais do evento para a comunidade",
            label_msgid='PyConBrasil_label_usoImagem',
            description_msgid='PyConBrasil_help_usoImagem',
            i18n_domain='PyConBrasil',
        ),
        read_permission="View"
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

Trabalho_schema = schema.copy()

##code-section after-schema #fill in your manual code here
##/code-section after-schema

class Trabalho(UIDRenamer):
    """Classe abstrata com base comum aos trabalhos submetidos ao
    evento.
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(UIDRenamer,'__implements__',()),)

    allowed_content_types = []
    _at_rename_after_creation = True

    schema = Trabalho_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    security.declarePrivate('getTrilhas')
    def getTrilhas(self):
        """Retorna as trilhas disponíveis
        """
        parent = self.aq_inner.aq_parent
        return parent.getTrilhas() or []

    # Manually created methods

    def Description(self):
        """Retorna o resumo do objeto no lugar de description
        """
        return self.getResumo()

    def Title(self):
        """Retorna o titulo do objeto no lugar de title
        """
        return self.getTitulo()


# end of class Trabalho

##code-section module-footer #fill in your manual code here
##/code-section module-footer






# -*- coding: utf-8 -*-
#
# File: Inscricao.py
#
# Copyright (c) 2007 by Associação Python Brasil
# Generator: ArchGenXML 
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PyConBrasil.UIDRenamer import UIDRenamer
from Products.PyConBrasil.config import *

##code-section module-header #fill in your manual code here
import transaction
from Products.CMFCore.utils import getToolByName
##/code-section module-header

schema = Schema((

    StringField(
        name='nome',
        widget=StringWidget(
            description="Informe o seu nome completo.",
            label='Nome',
            label_msgid='PyConBrasil_label_nome',
            description_msgid='PyConBrasil_help_nome',
            i18n_domain='PyConBrasil',
        ),
        required=1
    ),

    StringField(
        name='sexo',
        widget=SelectionWidget(
            description="Informe o seu sexo.",
            label='Sexo',
            label_msgid='PyConBrasil_label_sexo',
            description_msgid='PyConBrasil_help_sexo',
            i18n_domain='PyConBrasil',
        ),
        enforceVocabulary=1,
        vocabulary=['Feminino', 'Masculino'],
        required=1
    ),

    StringField(
        name='email',
        widget=StringWidget(
            label="E-Mail",
            description="Informe o seu endereço eletrônico.",
            label_msgid='PyConBrasil_label_email',
            description_msgid='PyConBrasil_help_email',
            i18n_domain='PyConBrasil',
        ),
        required=1,
        validators=('isEmail',)
    ),

    StringField(
        name='telefone',
        widget=StringWidget(
            description="Informe o seu telefone para contato em caso de necessidade. Incluindo o código DDD.",
            size=14,
            maxlength=20,
            label='Telefone',
            label_msgid='PyConBrasil_label_telefone',
            description_msgid='PyConBrasil_help_telefone',
            i18n_domain='PyConBrasil',
        )
    ),

    StringField(
        name='cidade',
        widget=StringWidget(
            description="Informe o nome da cidade em que você reside.",
            label='Cidade',
            label_msgid='PyConBrasil_label_cidade',
            description_msgid='PyConBrasil_help_cidade',
            i18n_domain='PyConBrasil',
        ),
        required=1
    ),

    StringField(
        name='estado',
        widget=SelectionWidget(
            description="Selecione o Estado em que você reside.",
            label='Estado',
            label_msgid='PyConBrasil_label_estado',
            description_msgid='PyConBrasil_help_estado',
            i18n_domain='PyConBrasil',
        ),
        enforceVocabulary=1,
        vocabulary=ESTADOS,
        required=1
    ),

    StringField(
        name='endereco',
        widget=StringWidget(
            description="Informe o endereço completo em que você reside. Será utilizado caso seja necessário enviar algo para você como por exemplo o certificado de participação.",
            condition="not:object/emPreInscricao",
            label="Endereço",
            label_msgid='PyConBrasil_label_endereco',
            description_msgid='PyConBrasil_help_endereco',
            i18n_domain='PyConBrasil',
        )
    ),

    StringField(
        name='instituicao',
        widget=StringWidget(
            description="Informe o nome da instituição em que você estuda, trabalha ou representa.",
            condition="not:object/emPreInscricao",
            label="Instituição",
            label_msgid='PyConBrasil_label_instituicao',
            description_msgid='PyConBrasil_help_instituicao',
            i18n_domain='PyConBrasil',
        )
    ),

    StringField(
        name='tipo',
        widget=SelectionWidget(
            description=("Tipo da inscrição que está sendo realizada. "
                         "Estudantes ou Membros APyB: R$ 25,00. "
                         "Membros SBC ou ABRAWEB: R$ 35,00. "
                         "Público em geral: R$ 45,00. "
                         "Palestrantes: isento."),
            condition="not:object/emPreInscricao",
            label='Tipo',
            label_msgid='PyConBrasil_label_tipo',
            description_msgid='PyConBrasil_help_tipo',
            i18n_domain='PyConBrasil',
        ),
        required=1,
        vocabulary=(
            ('1', 'Estudante ou Membro APyB'),
            ('2', 'Membro SBC ou Membro ABRAWEB'),
            ('3', 'Público em geral'),
            ('4', 'Palestrante'),
        ),
    ),

    BooleanField(
        name='paga',
        widget=BooleanWidget(
            visible=0,
            label='Paga',
            label_msgid='PyConBrasil_label_paga',
            i18n_domain='PyConBrasil',
        )
    ),

    ReferenceField(
        name='treinamentos',
        widget=ReferenceWidget(
            description="Selecione os treinamentos que você deseja participar.",
            format="select",
            visible=0,
            condition="not:object/emPreInscricao",
            label='Treinamentos',
            label_msgid='PyConBrasil_label_treinamentos',
            description_msgid='PyConBrasil_help_treinamentos',
            i18n_domain='PyConBrasil',
        ),
        allowed_types=('Treinamento',),
        multiValued=1,
        relationship='Inscricao_Treinamento'
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

Inscricao_schema = BaseSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here

Inscricao_schema['title'].required = 0
Inscricao_schema['title'].widget.visible = {'view':'invisible', 'edit':'invisible'}

##/code-section after-schema

class Inscricao(UIDRenamer, BaseContent):
    """Inscricao efetiva do participante do evento.
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(UIDRenamer,'__implements__',()),) + (getattr(BaseContent,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Inscrição'

    meta_type = 'Inscricao'
    portal_type = 'Inscricao'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 0
    content_icon = 'inscricao_icon.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "Inscrição de um participante no evento."
    typeDescMsgId = 'description_edit_inscricao'

    _at_rename_after_creation = True

    schema = Inscricao_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    # Manually created methods

    def Title(self):
        """Retorna o nome como título do objeto.
        """
        return self.getNome()


def modify_fti(fti):
    # Hide unnecessary tabs (usability enhancement)
    for a in fti['actions']:
        if a['id'] in ['metadata', 'sharing']:
            a['visible'] = 0
    return fti

registerType(Inscricao, PROJECTNAME)
# end of class Inscricao

##code-section module-footer #fill in your manual code here
##/code-section module-footer






# -*- coding: utf-8 -*-

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'


__author__  = '''Simples Consultoria'''
__docformat__ = 'plaintext'

# Python imports
import StringIO
from cStringIO import StringIO
import string

from Products.CMFCore.utils import getToolByName
from Products.Archetypes import listTypes

# Config

def install(self):
    out=StringIO()
    
    setup_tool = getToolByName(self, 'portal_setup')
    
    setup_tool.runAllImportStepsFromProfile("profile-Products.PyConBrasil:default", purge_old=False)

    out.write('Installation completed.\n')
    return out.getvalue()

def uninstall(self):
    out=StringIO()
    return out.getvalue()




# -*- coding: utf-8 -*-
from Products.Archetypes.public import DisplayList

ESTADOS = DisplayList((
    ('AC', u'Acre'),
    ('AL', u'Alagoas'),
    ('AP', u'Amapá'),
    ('AM', u'Amazonas'),
    ('BA', u'Bahia'),
    ('CE', u'Ceará'),
    ('DF', u'Distrito Federal'),
    ('ES', u'Espírito Santo'),
    ('GO', u'Goiás'),
    ('MA', u'Maranhão'),
    ('MT', u'Mato Grosso'),
    ('MS', u'Mato Grosso do Sul'),
    ('MG', u'Minas Gerais'),
    ('PA', u'Pará'),
    ('PB', u'Paraíba'),
    ('PR', u'Paraná'),
    ('PE', u'Pernambuco'),
    ('PI', u'Piauí'),
    ('RJ', u'Rio de Janeiro'),
    ('RN', u'Rio Grande do Norte'),
    ('RS', u'Rio Grande do Sul'),
    ('RO', u'Rondônia'),
    ('RR', u'Roraima'),
    ('SC', u'Santa Catarina'),
    ('SP', u'São Paulo'),
    ('SE', u'Sergipe'),
    ('TO', u'Tocantins'),
    ('Outro', u'Outro / Fora do Brasil'),
))




# -*- coding: utf-8 -*-
#
# File: Palestra.py
#
# Copyright (c) 2007 by Associação Python Brasil
# Generator: ArchGenXML 
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PyConBrasil.Trabalho import Trabalho
from Products.PyConBrasil.config import *

##code-section module-header #fill in your manual code here
##/code-section module-header

schema = Schema((

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

Palestra_schema = BaseSchema.copy() + \
    getattr(Trabalho, 'schema', Schema(())).copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here

Palestra_schema['title'].required = 0
Palestra_schema['title'].widget.visible = {'view':'invisible', 'edit':'invisible'}

##/code-section after-schema

class Palestra(Trabalho, BaseContent):
    """Palestra do evento. Esta palestra depende da aprovacao pela
    comissao do evento.
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(Trabalho,'__implements__',()),) + (getattr(BaseContent,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Palestra'

    meta_type = 'Palestra'
    portal_type = 'Palestra'
    allowed_content_types = [] + list(getattr(Trabalho, 'allowed_content_types', []))
    filter_content_types = 0
    global_allow = 0
    content_icon = 'palestra_icon.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "Inscrição de uma palestra no evento."
    typeDescMsgId = 'description_edit_palestra'

    _at_rename_after_creation = True

    schema = Palestra_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    security.declarePrivate('getVocTempo')
    def getVocTempo(self):
        """
        """
        vocTempo = ['Indiferente',
                    '30 minutos',
                    '45 minutos',
                    '60 minutos']
        return tuple(vocTempo)

def modify_fti(fti):
    # Hide unnecessary tabs (usability enhancement)
    for a in fti['actions']:
        if a['id'] in ['metadata', 'sharing']:
            a['visible'] = 0
    return fti

registerType(Palestra, PROJECTNAME)
# end of class Palestra

##code-section module-footer #fill in your manual code here
##/code-section module-footer






# -*- coding: utf-8 -*-
#
# File: Imprensa.py
#
# Copyright (c) 2007 by Associação Python Brasil
# Generator: ArchGenXML 
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PyConBrasil.UIDRenamer import UIDRenamer
from Products.PyConBrasil.config import *

##code-section module-header #fill in your manual code here
import transaction##/code-section module-header

schema = Schema((

    StringField(
        name='nome',
        widget=StringWidget(
            description="Informe o seu nome completo.",
            label='Nome',
            label_msgid='PyConBrasil_label_nome',
            description_msgid='PyConBrasil_help_nome',
            i18n_domain='PyConBrasil',
        ),
        required=1
    ),

    StringField(
        name='email',
        widget=StringWidget(
            label="E-Mail",
            description="Informe o seu endereço eletrônico.",
            label_msgid='PyConBrasil_label_email',
            description_msgid='PyConBrasil_help_email',
            i18n_domain='PyConBrasil',
        ),
        required=1,
        validators=('isEmail',)
    ),

    StringField(
        name='telefone',
        widget=StringWidget(
            description="Informe o seu telefone para contato em caso de necessidade. Incluindo o código DDD.",
            size=14,
            maxlength=20,
            label='Telefone',
            label_msgid='PyConBrasil_label_telefone',
            description_msgid='PyConBrasil_help_telefone',
            i18n_domain='PyConBrasil',
        ),
        required=1
    ),

    StringField(
        name='instituicao',
        widget=StringWidget(
            description="Informe o nome da instituição de imprensa que você representa.",
            label="Instituição",
            label_msgid='PyConBrasil_label_instituicao',
            description_msgid='PyConBrasil_help_instituicao',
            i18n_domain='PyConBrasil',
        ),
        required=1
    ),

    TextField(
        name='observacoes',
        index=":schema",
        widget=TextAreaWidget(
            description="Descreva aqui qualquer observação que você achar pertinente.",
            label="Observações",
            label_msgid='PyConBrasil_label_observacoes',
            description_msgid='PyConBrasil_help_observacoes',
            i18n_domain='PyConBrasil',
        )
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

Imprensa_schema = BaseSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here

Imprensa_schema['title'].required = 0
Imprensa_schema['title'].widget.visible = {'view':'invisible', 'edit':'invisible'}

##/code-section after-schema

class Imprensa(UIDRenamer, BaseContent):
    """Profissional da imprensa que acompanhara o evento fazendo
    registros jornalisticos.
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(UIDRenamer,'__implements__',()),) + (getattr(BaseContent,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Imprensa'

    meta_type = 'Imprensa'
    portal_type = 'Imprensa'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 0
    content_icon = 'imprensa_icon.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "Inscrição de um profissional ou órgão de imprensa."
    typeDescMsgId = 'description_edit_imprensa'

    _at_rename_after_creation = True

    schema = Imprensa_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    # Manually created methods

    def Title(self):
        """Retorna o nome como titulo
        """

        return self.getNome()


def modify_fti(fti):
    # Hide unnecessary tabs (usability enhancement)
    for a in fti['actions']:
        if a['id'] in ['metadata', 'sharing']:
            a['visible'] = 0
    return fti

registerType(Imprensa, PROJECTNAME)
# end of class Imprensa

##code-section module-footer #fill in your manual code here
##/code-section module-footer






# -*- coding: utf-8 -*-

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'

import logging
logger = logging.getLogger('PyConBrasil')
logger.debug('Installing Product')

try:
    import CustomizationPolicy
except ImportError:
    CustomizationPolicy = None

from Globals import package_home
from Products.CMFCore import utils as cmfutils

from Products.CMFCore import permissions as CMFCorePermissions

from Products.CMFCore import DirectoryView
from Products.CMFPlone.utils import ToolInit
from Products.Archetypes.atapi import *
from Products.Archetypes import listTypes
from Products.Archetypes.utils import capitalize

import os, os.path

from Products.PyConBrasil.config import *

def initialize(context):

    import Inscricoes
    import Inscricao
    import Trabalho
    import Treinamento
    import Palestra
    import PalestraRelampago
    import Imprensa
    import UIDRenamer

    # Initialize portal content
    all_content_types, all_constructors, all_ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    cmfutils.ContentInit(
        PROJECTNAME + ' Content',
        content_types      = all_content_types,
        permission         = DEFAULT_ADD_CONTENT_PERMISSION,
        extra_constructors = all_constructors,
        fti                = all_ftis,
        ).initialize(context)

    for i in range(0,len(all_content_types)):
        klassname=all_content_types[i].__name__
        if not klassname in ADD_CONTENT_PERMISSIONS:
            continue

        context.registerClass(meta_type   = all_ftis[i]['meta_type'],
                              constructors= (all_constructors[i],),
                              permission  = ADD_CONTENT_PERMISSIONS[klassname])




# -*- coding: utf-8 -*-

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'

from Products.CMFCore.permissions import setDefaultRoles

PROJECTNAME = "Products.PyConBrasil"

DEFAULT_ADD_CONTENT_PERMISSION = "Add portal content"
setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner'))
ADD_CONTENT_PERMISSIONS = {
    'Inscricao': 'PyConBrasil: Add Inscricao',
    'Treinamento': 'PyConBrasil: Add Treinamento',
    'Palestra': 'PyConBrasil: Add Palestra',
    'PalestraRelampago': 'PyConBrasil: Add PalestraRelampago',
    'Imprensa': 'PyConBrasil: Add Imprensa',
}

setDefaultRoles('PyConBrasil: Add Inscricao', ('Manager', 'Member', 'Anonymous'))
setDefaultRoles('PyConBrasil: Add Treinamento', ('Manager', 'Member', 'Anonymous'))
setDefaultRoles('PyConBrasil: Add Palestra', ('Manager', 'Member', 'Anonymous'))
setDefaultRoles('PyConBrasil: Add PalestraRelampago', ('Manager', 'Member', 'Anonymous'))
setDefaultRoles('PyConBrasil: Add Imprensa', ('Manager', 'Member', 'Anonymous'))

product_globals = globals()

try:
    from Products.PyConBrasil.AppConfig import *
except ImportError:
    pass



# -*- coding: utf-8 -*-
#
# File: Inscricoes.py
#
# Copyright (c) 2007 by Associação Python Brasil
# Generator: ArchGenXML 
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Jean Rodrigo Ferri / Dorneles Treméa / Fabiano Weimar / Rodrigo Senra /
Érico Andrei <contato@pythobrasil.com.br>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PyConBrasil.config import *

##code-section module-header #fill in your manual code here
from urllib import quote
from Products.CMFCore.utils import getToolByName
##/code-section module-header

schema = Schema((

    TextField(
        name='texto',
        allowable_content_types=('text/plain', 'text/structured', 'text/html', 'application/msword',),
        widget=RichWidget(
            description="Informe o texto promocional que você deseja usar para esta pasta de inscrições.",
            label='Texto',
            label_msgid='PyConBrasil_label_texto',
            description_msgid='PyConBrasil_help_texto',
            i18n_domain='PyConBrasil',
        ),
        default_output_type='text/html'
    ),

    LinesField(
        name='trilhas',
        widget=LinesField._properties['widget'](
            rows="20",
            visible={'view':'invisible','edit':'visible'},
            label="Trilhas do evento",
            description="Informe, uma por linha, as trilhas disponíveis no evento.",
            label_msgid='PyConBrasil_label_trilhas',
            description_msgid='PyConBrasil_help_trilhas',
            i18n_domain='PyConBrasil',
        )
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

Inscricoes_schema = BaseBTreeFolderSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
##/code-section after-schema

class Inscricoes(BaseBTreeFolder):
    """Pasta que contem todas as inscricoes de participantes,
    palestras, treinamentos, etc...
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(BaseBTreeFolder,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Inscrições'

    meta_type = 'Inscricoes'
    portal_type = 'Inscricoes'
    allowed_content_types = ['Inscricao', 'Treinamento', 'Palestra', 'PalestraRelampago', 'Imprensa']
    filter_content_types = 1
    global_allow = 1
    content_icon = 'inscricoes_icon.gif'
    immediate_view = 'base_view'
    default_view = 'inscricoes_view'
    suppl_views = ()
    typeDescription = "Controle de Inscrições."
    typeDescMsgId = 'description_edit_inscricoes'
    allow_discussion = 1


    actions =  (


       {'action': "string:${object_url}/inscricoes_view",
        'category': "object",
        'id': 'view',
        'name': 'View',
        'permissions': ("View",),
        'condition': 'python:1'
       },


       {'action': "string:${object_url}/pre_inscricao_list",
        'category': "object",
        'id': 'pre_inscricao_list',
        'name': 'Pré-Inscrições',
        'permissions': ("Review portal content",),
        'condition': 'python:1'
       },


       {'action': "string:${object_url}/inscricao_list",
        'category': "object",
        'id': 'inscricao_list',
        'name': 'Inscrições',
        'permissions': ("Review portal content",),
        'condition': 'python:1'
       },


       {'action': "string:${object_url}/palestra_list",
        'category': "object",
        'id': 'palestra_list',
        'name': 'Palestras',
        'permissions': ("Review portal content",),
        'condition': 'python:1'
       },


       {'action': "string:${object_url}/palestra_relampago_list",
        'category': "object",
        'id': 'palestra_relampago_list',
        'name': 'Palestras Relâmpago',
        'permissions': ("Review portal content",),
        'condition': 'python:1'
       },


       {'action': "string:${object_url}/treinamento_list",
        'category': "object",
        'id': 'treinamento_list',
        'name': 'Treinamentos',
        'permissions': ("Review portal content",),
        'condition': 'python:1'
       },


       {'action': "string:${object_url}/imprensa_list",
        'category': "object",
        'id': 'imprensa_list',
        'name': 'Imprensa',
        'permissions': ("Review portal content",),
        'condition': 'python:1'
       },


    )

    _at_rename_after_creation = True

    schema = Inscricoes_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    security.declarePrivate('emEstado')
    def emEstado(self, estado):
        """Testa se o objeto está em um determinado estado.
        """
        portal_workflow = getToolByName(self, 'portal_workflow')
        review_state = portal_workflow.getInfoFor(self, 'review_state', None)
        return review_state == estado

    security.declarePublic('emInscricao')
    def emInscricao(self):
        """Testa se o objeto está aberto para inscrições, o que
        corresponde ao estado inscricoes do workflow.
        """
        return self.emEstado('inscricoes')

    security.declarePublic('emPreInscricao')
    def emPreInscricao(self):
        """Testa se o objeto está aberto para pré-inscrições, o que
        corresponde ao estado pre-inscricoes do workflow.
        """
        return self.emEstado('pre-inscricoes')

    security.declarePublic('confirmaInscricao')
    def confirmaInscricao(self, key):
        """Inicia o processo de confirmação de uma inscrição.
        """
        redirect = self.REQUEST.RESPONSE.redirect
        reference_catalog = getToolByName(self, 'reference_catalog')
        inscricao = reference_catalog.lookupObject(key)

        if inscricao is None or inscricao.portal_type != 'Inscricao':
            url = self.absolute_url()
            msg = 'Inscrição Inválida.'
            redirect = self.REQUEST.RESPONSE.redirect
            return redirect("%s?portal_status_message=%s" % (url, quote(msg)))

        portal_workflow = getToolByName(self, 'portal_workflow')
        review_state = portal_workflow.getInfoFor(inscricao, 'review_state')

        if review_state == 'pre-inscrito':
            portal_workflow.doActionFor(inscricao, 'iniciar_confirmacao')

        url = inscricao.absolute_url()
        msg = 'Preencha os campos restantes para confirmar sua inscrição.'
        return redirect('%s/edit?portal_status_message=%s' % (url, quote(msg)))


registerType(Inscricoes, PROJECTNAME)
# end of class Inscricoes

##code-section module-footer #fill in your manual code here
##/code-section module-footer






from StringIO import StringIO
import logging
logger = logging.getLogger('sc.nassau.portalcorporativo: setuphandlers')
import transaction
from Products.CMFCore.utils import getToolByName

def isNotOurProfile(context):
    return context.readDataFile("pyconbrasil.txt") is None

def addToListProperty(context, out, propertySheet, property, value):
    """Add the given value to the list in the given property"""
    current = list(propertySheet.getProperty(property))
    if value not in current:
        current.append(value)
        propertySheet.manage_changeProperties(**{property : current})

    print >> out, "Added %s to %s" % (value, property)

def addFormControllerAction(context, out, controller, template, status,
                                contentType, button, actionType, action):
    """Add the given action to the portalFormController"""
    controller.addFormAction(template, status, contentType,
                                button, actionType, action)
    print >> out, "Added action %s to %s" % (action, template)

def handle_form_controllers(context):
    
    if isNotOurProfile(context):return
    out = StringIO()
    site = context.getSite()
    controller = getToolByName(site, 'portal_form_controller')
    addFormControllerAction(site, out, controller, 'validate_integrity',
                            'success', 'Imprensa', None, 'traverse_to', 'string:imprensa_save')
    addFormControllerAction(site, out, controller, 'validate_integrity',
                            'success', 'Inscricao', None, 'traverse_to', 'string:inscricao_save')
    addFormControllerAction(site, out, controller, 'validate_integrity',
                            'success', 'PalestraRelampago', None, 'traverse_to', 'string:palestra_relampago_save')
    addFormControllerAction(site, out, controller, 'validate_integrity',
                            'success', 'Palestra', None, 'traverse_to', 'string:palestra_save')
    addFormControllerAction(site, out, controller, 'validate_integrity',
                            'success', 'Treinamento', None, 'traverse_to', 'string:treinamento_save')

    
